#!/bin/bash
# *******************************************************************************
# * Licensed Materials - Property of IBM and/or HCL 
# * (c) Copyright HCL Technologies Ltd. 2021. All Rights Reserved. 
# * 
# * Note to U.S. Government Users Restricted Rights: 
# * Use, duplication or disclosure restricted by GSA ADP Schedule 
# * Contract with IBM Corp. 
# *******************************************************************************

# ::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
# ::   
# :: OVERVIEW:
# :: Note This script is used to install the UITestAgent.
# ::
# :: USAGE  UITestTestAgentSetup.sh
# ::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::

# ::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::

baseDir="$(cd "$(dirname "${BASH_SOURCE[0]}" )" &> /dev/null && pwd )"
installDir=$(dirname "$baseDir")

if [ "$(uname)" == "Darwin" ];
then
	sed -i'' -e 's|#PATH#|'$baseDir'|g' ui.test.agent.plist
    sed -i'' -e 's|#JAVA-HOME#|'$installDir/jdk/Contents/Home'|g' ui.test.agent.plist
    
     if [ -d "/Users/$(logname)/Library/Android/sdk" ];
    then
    	 sed -i'' -e 's|#ANDROID-HOME#|'/Users/$(logname)/Library/Android/sdk'|g' ui.test.agent.plist
    
    elif [ -d "$ANDROID_HOME" ];
    then
        sed -i'' -e 's|#ANDROID-HOME#|'$ANDROID_HOME'|g' ui.test.agent.plist
    
    else
    	echo "Android Sdk not installed on default path.. "
    fi
   
    
    cp $baseDir/ui.test.agent.plist /Library/LaunchAgents/
    rm -r $baseDir/ui.test.agent.plist-e
    launchctl load /Library/LaunchAgents/ui.test.agent.plist
    
    echo UITestAgent installed successfully!
else
	installDir=$(dirname "$baseDir")
	sed -i'' -e 's|#INSTALL_DIR#|'$installDir'|g' ui-test-agent.service
	sed -i'' -e 's|#JAVA-HOME#|'$installDir/jdk'|g' ui-test-agent.service
    
    if [ -d "/home/$(logname)/Android/Sdk" ];
    then
    	sed -i'' -e 's|#ANDROID-HOME#|'/home/$(logname)/Android/Sdk'|g' ui-test-agent.service
   
   	elif [ -d "$ANDROID_HOME" ];
    then
        sed -i'' -e 's|#ANDROID-HOME#|'ANDROID_HOME'|g' ui-test-agent.service
 
    else
    	echo "Android Sdk not installed on default path.. "
    fi
        
	cp $baseDir/ui-test-agent.service /etc/systemd/system/
	systemctl daemon-reload
	systemctl enable ui-test-agent.service
	systemctl start ui-test-agent.service &
	
	echo UITestAgent installed successfully!
fi
